==> hubzero-submit-client_2.5.5.orig.tar.gz: hubzero-submit-client-2.5.5/setup.py <==
# @package      hubzero-submit-client
# @file         setup.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
'''
hubzero-submit-client is a set of python
routines for the hubzero-submit client.
'''


classifiers = '''\
Development Status :: 5 - Production/Stable
Intended Audience :: Science/Research
License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)
Operating System :: POSIX :: Linux
Programming Language :: Python :: 2.6
Topic :: System :: Distributed Computing \
'''.split('\n')

import os
from distutils.core import setup

setup(
    name='submit-client',
    version='2.5.5',
    license = 'GNU LGPL 3+',
    description = 'set of python routines for the hubzero-submit-client package',
    classifiers = classifiers,
    url='http://hubzero.org',
    author='Steven Clark',
    author_email='clarks@purdue.edu',
    packages=['hubzero','hubzero.submit'],
)

# vim:ts=4 sw=4 et

==> hubzero-submit-client_2.5.6.orig.tar.gz: hubzero-submit-client-2.5.6/setup.py <==
# @package      hubzero-submit-client
# @file         setup.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
'''
hubzero-submit-client is a set of python
routines for the hubzero-submit client.
'''


classifiers = '''\
Development Status :: 5 - Production/Stable
Intended Audience :: Science/Research
License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)
Operating System :: POSIX :: Linux
Programming Language :: Python
Topic :: System :: Distributed Computing \
'''.split('\n')

import os
from distutils.core import setup

setup(
    name='submit-client',
    version='2.5.6',
    license = 'GNU LGPL 3+',
    description = 'set of python routines for the hubzero-submit-client package',
    classifiers = classifiers,
    url='http://hubzero.org',
    author='Steven Clark',
    author_email='clarks@purdue.edu',
    packages=['hubzero','hubzero.submit'],
)

# vim:ts=4 sw=4 et
